@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 19's 3.14 kernel.
+# This is a kernel build script for Fedora 20's 3.17 kernel.
 #
 
 die () {
@@ -12,12 +12,12 @@ yum -y install tar wget rpm-build make gcc patch redhat-rpm-config xmlto asciido
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.14.17-100.fc19.src.rpm ]
+if [ ! -r kernel-3.17.3-200.fc20.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/20/SRPMS/kernel-3.14.17-100.fc19.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/20/SRPMS/kernel-3.17.3-200.fc20.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-3.14.17-100.fc19.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-3.14.17-100.fc19.src.rpm || die "Can't install source package."
+rpm --checksig kernel-3.17.3-200.fc20.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-3.17.3-200.fc20.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
 if [ ! -r ccs-patch-1.8.3-20140915.tar.gz ]
@@ -39,19 +39,7 @@ patch << "EOF" || die "Can't patch spec file."
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -434,6 +434,11 @@
- #
- %define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.2.5-7.fc17, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2, device-mapper-libs < 1.02.63-2, mdadm < 3.2.1-5
- 
-+# TOMOYO Linux
-+%define with_modsign 0
-+%define _enable_debug_packages 0
-+%define with_debuginfo 0
-+
- #
- # Then a series of requirements that are distribution specific, either
- # because we add patches for something, or the older versions have
-@@ -490,7 +495,7 @@
+@@ -477,7 +477,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -60,7 +48,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2 and Redistributable, no modification permitted
  URL: http://www.kernel.org/
-@@ -949,7 +954,7 @@
+@@ -959,7 +959,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
  Requires: perl\
@@ -69,27 +57,27 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -969,7 +974,7 @@
- Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:.%{1}}\
- Requires: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
+@@ -979,7 +979,7 @@
+ Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:+%{1}}\
+ Requires: kernel-uname-r = %{KVERREL}%{?1:+%{1}}\
  AutoReqProv: no\
 -%description -n kernel%{?variant}%{?1:-%{1}}-modules-extra\
 +%description -n ccs-kernel%{?variant}%{?1:-%{1}}-modules-extra\
  This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
  %{nil}
  
-@@ -1471,6 +1476,10 @@
+@@ -1521,6 +1521,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
 +tar -zxf %_sourcedir/ccs-patch-1.8.3-20140915.tar.gz
-+patch -sp1 < patches/ccs-patch-3.14-fedora-19.diff
++patch -sp1 < patches/ccs-patch-3.17-fedora-20.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1493,6 +1502,18 @@
+@@ -1545,6 +1549,17 @@
  for i in *.config
  do
    mv $i .config
@@ -104,7 +92,6 @@ patch << "EOF" || die "Can't patch spec file."
 +  echo '# CONFIG_DEFAULT_SECURITY_TOMOYO is not set' >> .config
 +  # TOMOYO Linux 1.8
 +  cat config.ccs >> .config
-+  sed -i -e 's:CONFIG_DEBUG_INFO=.*:# CONFIG_DEBUG_INFO is not set:' -- .config
    Arch=`head -1 .config | cut -b 3-`
    make ARCH=$Arch listnewconfig | grep -E '^CONFIG_' >.newoptions || true
  %if %{listnewconfig_fail}
